Hash

Struct Hash 

pub struct Hash { /* private fields */ }

Implementations

Source

impl Hash

pub fn new() -> HashResult<Self>

pub fn make(&self, value: &str) -> HashResult<String>

pub fn check(&self, value: &str, hashed: &str) -> bool

Methods from Deref<Target = Argon2<'static>>

pub fn hash_password_into( &self, pwd: &[u8], salt: &[u8], out: &mut [u8], ) -> Result<(), Error>

Hash a password and associated parameters into the provided output buffer.

pub fn hash_password_into_with_memory( &self, pwd: &[u8], salt: &[u8], out: &mut [u8], memory_blocks: impl AsMut<[Block]>, ) -> Result<(), Error>

Hash a password and associated parameters into the provided output buffer.

This method takes an explicit memory_blocks parameter which allows the caller to provide the backing storage for the algorithm’s state:

  • Users with the alloc feature enabled can use Argon2::hash_password_into to have it allocated for them.
  • no_std users on “heapless” targets can use an array of the Block type to stack allocate this buffer.
pub fn fill_memory( &self, pwd: &[u8], salt: &[u8], memory_blocks: impl AsMut<[Block]>, ) -> Result<(), Error>

Use a password and associated parameters only to fill the given memory blocks.

This method omits the calculation of a hash and can be used when only the filled memory is required. It is not necessary to call this method before calling any of the hashing functions.

pub fn params(&self) -> &Params

Get default configured Params.